@@ -23,8 +23,8 @@
 #define LIBSOUP_I_HAVE_READ_BUG_594377_AND_KNOW_SOUP_PASSWORD_MANAGER_MIGHT_GO_AWAY
 #define NSPLUGINWRAPPER_SETUP "/usr/bin/mozilla-plugin-config"
 
-#include "eel-gconf-extensions.h"
 #include "ephy-embed-single.h"
+#include "ephy-embed-shell.h"
 #include "ephy-embed-prefs.h"
 #include "ephy-embed-type-builtins.h"
 #include "ephy-debug.h"
@@ -33,12 +33,15 @@
 #include "ephy-signal-accumulator.h"
 #include "ephy-permission-manager.h"
 #include "ephy-profile-migration.h"
+#include "ephy-prefs.h"
+#include "ephy-settings.h"
 
 #ifdef ENABLE_CERTIFICATE_MANAGER
 #include "ephy-certificate-manager.h"
 #endif
 
 #include <webkit/webkit.h>
+#include <glib/gi18n.h>
 #include <libsoup/soup-gnome.h>
 #include <gnome-keyring.h>
 
@@ -48,6 +51,7 @@ struct _EphyEmbedSinglePrivate {
   guint online : 1;
 
   GHashTable *form_auth_data;
+  WebKitSoupCache *cache;
 };
 
 enum {
@@ -230,6 +234,21 @@ remove_form_auth_data (gpointer key, gpointer value, gpointer user_data)
     free_form_auth_data_list ((GSList*)value);
 }
 
+static void
+ephy_embed_single_dispose (GObject *object)
+{
+  EphyEmbedSinglePrivate *priv = EPHY_EMBED_SINGLE (object)->priv;
+
+  if (priv->cache) {
+    webkit_soup_cache_flush (priv->cache);
+    webkit_soup_cache_dump (priv->cache);
+    g_object_unref (priv->cache);
+    priv->cache = NULL;
+  }
+
+  G_OBJECT_CLASS (ephy_embed_single_parent_class)->dispose (object);
+}
+
 static void
 ephy_embed_single_finalize (GObject *object)
 {
@@ -268,6 +287,7 @@ ephy_embed_single_class_init (EphyEmbedSingleClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   object_class->finalize = ephy_embed_single_finalize;
+  object_class->dispose = ephy_embed_single_dispose;
   object_class->get_property = ephy_embed_single_get_property;
   object_class->set_property = ephy_embed_single_set_property;
 
@@ -317,26 +337,6 @@ ephy_embed_single_class_init (EphyEmbedSingleClass *klass)
                 G_TYPE_STRING,
                 G_TYPE_STRING);
 
-  /**
-   * EphyEmbedSingle::add-sidebar:
-   * @single:
-   * @url: The url of the sidebar to be added
-   * @title: The title of the sidebar to be added
-   *
-   * The ::add-sidebar signal is emitted when the user clicks a javascript link that
-   * requests adding a url to the sidebar.
-   **/
-  g_signal_new ("add-sidebar",
-                EPHY_TYPE_EMBED_SINGLE,
-                G_SIGNAL_RUN_LAST,
-                G_STRUCT_OFFSET (EphyEmbedSingleClass, add_sidebar),
-                g_signal_accumulator_true_handled, NULL,
-                ephy_marshal_BOOLEAN__STRING_STRING,
-                G_TYPE_BOOLEAN,
-                2,
-                G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
-                G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
-
   /**
    * EphyEmbedSingle::add-search-engine
    * @single:
@@ -458,6 +458,15 @@ ephy_certificate_manager_iface_init (EphyCertificateManagerIface *iface)
 
 #endif /* ENABLE_CERTIFICATE_MANAGER */
 
+static void
+cache_size_cb (GSettings *settings,
+               char *key,
+               EphyEmbedSingle *single)
+{
+  int new_cache_size = g_settings_get_int (EPHY_SETTINGS_WEB, EPHY_PREFS_CACHE_SIZE);
+  webkit_soup_cache_set_max_size (single->priv->cache, new_cache_size);
+}
+
 /**
  * ephy_embed_single_initialize:
  * @single: the #EphyEmbedSingle
@@ -472,6 +481,8 @@ ephy_embed_single_initialize (EphyEmbedSingle *single)
   SoupCookieJar *jar;
   char *filename;
   char *cookie_policy;
+  char *cache_dir;
+  EphyEmbedSinglePrivate *priv = single->priv;
 
   /* Initialise nspluginwrapper's plugins if available */
   if (g_file_test (NSPLUGINWRAPPER_SETUP, G_FILE_TEST_EXISTS) != FALSE)
@@ -481,11 +492,26 @@ ephy_embed_single_initialize (EphyEmbedSingle *single)
 
   session = webkit_get_default_session ();
 
+#ifdef GTLS_SYSTEM_CA_FILE
+  /* Check SSL certificates */
+
+  if (g_file_test (GTLS_SYSTEM_CA_FILE, G_FILE_TEST_EXISTS)) {
+    g_object_set (session,
+                  SOUP_SESSION_SSL_CA_FILE, GTLS_SYSTEM_CA_FILE,
+                  SOUP_SESSION_SSL_STRICT, FALSE,
+                  NULL);
+  } else {
+    g_warning (_("CA Certificates file we should use was not found, "\
+                 "all SSL sites will be considered to have a broken certificate."));
+  }
+#endif
+
   /* Store cookies in moz-compatible SQLite format */
   filename = g_build_filename (ephy_dot_dir (), "cookies.sqlite", NULL);
   jar = soup_cookie_jar_sqlite_new (filename, FALSE);
   g_free (filename);
-  cookie_policy = eel_gconf_get_string (CONF_SECURITY_COOKIES_ACCEPT);
+  cookie_policy = g_settings_get_string (EPHY_SETTINGS_WEB,
+                                         EPHY_PREFS_WEB_COOKIES_POLICY);
   ephy_embed_prefs_set_cookie_jar_policy (jar, cookie_policy);
   g_free (cookie_policy);
 
@@ -495,6 +521,21 @@ ephy_embed_single_initialize (EphyEmbedSingle *single)
   /* Use GNOME proxy settings through libproxy */
   soup_session_add_feature_by_type (session, SOUP_TYPE_PROXY_RESOLVER_GNOME);
 
+  /* WebKitSoupCache */
+  cache_dir = g_build_filename (g_get_user_cache_dir (), g_get_prgname (), NULL);
+  priv->cache = webkit_soup_cache_new (cache_dir, WEBKIT_SOUP_CACHE_SINGLE_USER);
+  g_free (cache_dir);
+
+  soup_session_add_feature (session, SOUP_SESSION_FEATURE (priv->cache));
+  /* Cache size in Mb: 1024 * 1024 */
+  webkit_soup_cache_set_max_size (priv->cache, g_settings_get_int (EPHY_SETTINGS_WEB, EPHY_PREFS_CACHE_SIZE) << 20);
+  webkit_soup_cache_load (priv->cache);
+
+  g_signal_connect (EPHY_SETTINGS_WEB,
+                    "changed::" EPHY_PREFS_CACHE_SIZE,
+                    G_CALLBACK (cache_size_cb),
+                    single);
+
 #ifdef SOUP_TYPE_PASSWORD_MANAGER
   /* Use GNOME keyring to store passwords. Only add the manager if we
      are not using a private session, otherwise we want any new
@@ -516,6 +557,7 @@ ephy_embed_single_initialize (EphyEmbedSingle *single)
 void
 ephy_embed_single_clear_cache (EphyEmbedSingle *single)
 {
+  webkit_soup_cache_clear (single->priv->cache);
 }
 
 /**
