@@ -32,11 +32,11 @@
 #include "ephy-embed-container.h"
 #include "ephy-extension.h"
 #include "ephy-file-helpers.h"
-#include "eel-gconf-extensions.h"
 #include "ephy-gui.h"
 #include "ephy-history-window.h"
 #include "ephy-notebook.h"
 #include "ephy-prefs.h"
+#include "ephy-settings.h"
 #include "ephy-shell.h"
 #include "ephy-stock-icons.h"
 #include "ephy-window.h"
@@ -375,6 +375,7 @@ session_delete (EphySession *session,
 	file = get_session_file (filename);
 
 	g_file_delete (file, NULL, NULL);
+	g_object_unref (file);
 }
 
 static void
@@ -523,6 +524,7 @@ session_command_autoresume (EphySession *session,
 
 	saved_session_file = get_session_file (SESSION_CRASHED);
 	saved_session_file_path = g_file_get_path (saved_session_file);
+	g_object_unref (saved_session_file);
 	crashed_session = g_file_test (saved_session_file_path, G_FILE_TEST_EXISTS);
 	
 	g_free (saved_session_file_path);
@@ -1596,6 +1598,7 @@ ephy_session_load (EphySession *session,
 
 	save_to_file = get_session_file (filename);
 	save_to_path = g_file_get_path (save_to_file);
+	g_object_unref (save_to_file);
 
 	doc = xmlParseFile (save_to_path);
 	g_free (save_to_path);
@@ -1667,14 +1670,18 @@ ephy_session_load (EphySession *session,
 
 			if (id && xmlStrEqual ((const xmlChar *) BOOKMARKS_EDITOR_ID, id))
 			{
-				if (!eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING))
+				if (!g_settings_get_boolean
+				    (EPHY_SETTINGS_LOCKDOWN,
+				     EPHY_PREFS_LOCKDOWN_BOOKMARK_EDITING))
 				{
 					widget = ephy_shell_get_bookmarks_editor (ephy_shell);
 				}
 			}
 			else if (id && xmlStrEqual ((const xmlChar *) HISTORY_WINDOW_ID, id))
 			{
-				if (!eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_HISTORY))
+				if (!g_settings_get_boolean
+				    (EPHY_SETTINGS_LOCKDOWN,
+				     EPHY_PREFS_LOCKDOWN_HISTORY))
 				{
 					widget = ephy_shell_get_history_window (ephy_shell);
 				}
