@@ -76,13 +76,12 @@ void		ephy_toolbar_set_favicon		(EphyToolbar *toolbar,
 void		ephy_toolbar_set_show_leave_fullscreen	(EphyToolbar *toolbar,
 							 gboolean show);
 
-void		ephy_toolbar_activate_location		(EphyToolbar *t);
+void		ephy_toolbar_activate_location		(EphyToolbar *toolbar);
 
-const char     *ephy_toolbar_get_location		(EphyToolbar *t);
+const char     *ephy_toolbar_get_location		(EphyToolbar *toolbar);
 
 void		ephy_toolbar_set_location		(EphyToolbar *toolbar,
-							 const char *address,
-							 const char *typed_address);
+							 const char *address);
 
 void		ephy_toolbar_set_navigation_actions	(EphyToolbar *toolbar,
 							 gboolean back,
